{% extends 'base.html' %}
{% load static %}

{% block title_text %}Красногорский комбинат автофургонов...{% endblock %}

{% block icon %}static/favicon.ico.png{% endblock %}

{% block js_code %}
{#    <script type="text/javascript" src="shifts.js"></script>#}
    <script type="text/javascript" src={% static "isc-ts/kaf-1.0.2.js" %}></script>
{% endblock %}

{% block start_page %}startPage(){% endblock %}
