# Generated by Django 2.2.3 on 2019-07-30 13:50

import bitfield.models
from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0076_pathes_virt_path'),
    ]

    operations = [
        migrations.CreateModel(
            name='Documents_mview',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('relevant', isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Актуальность')),
                ('file_document', models.TextField(verbose_name='Полный путь к файлу')),
                ('file_size', models.PositiveIntegerField(verbose_name='Размер файла')),
                ('file_modification_time', models.DateTimeField(blank=True, null=True, verbose_name='Дата время поcледнего модификации документа')),
                ('file_access_time', models.DateTimeField(blank=True, null=True, verbose_name='Дата время поcледнего доступа к документу')),
                ('file_change_time', models.DateTimeField(blank=True, null=True, verbose_name='Дата время изменнения документа')),
                ('props', bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий')), default=1)),
                ('load_error', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Documents MView',
                'db_table': 'kd_documents_mview',
                'managed': False,
            },
        ),
    ]
